/v1/projects/{project_id}/iou/vms/{vm_id} — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/iou/vms/{vm_id}

Contents

- /v1/projects/{project_id}/iou/vms/{vm_id}
  - GET /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes
    - Output
  - PUT /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes
    - Input
    - Output
  - DELETE /v1/projects/{project_id}/iou/vms/{vm_id}
    - Parameters
    - Response status codes

## GET /v1/projects/{project_id}/iou/vms/{vm_id}

Get a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Success
- 400: Invalid request
- 404: Instance doesn’t exist

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

## PUT /v1/projects/{project_id}/iou/vms/{vm_id}

Update a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 200: Instance updated
- 400: Invalid request
- 404: Instance doesn’t exist
- 409: Conflict

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
console |  | ['integer', 'null'] | console TCP port
ethernet_adapters |  | ['integer', 'null'] | How many ethernet adapters are connected to the IOU
initial_config |  | ['string', 'null'] | Initial configuration of the IOU
iourc_path |  | ['string', 'null'] | Path of iourc
l1_keepalives |  | ['boolean', 'null'] | Always up ethernet interface
name |  | ['string', 'null'] | IOU VM name
nvram |  | ['integer', 'null'] | Allocated NVRAM KB
path |  | ['string', 'null'] | Path of iou binary
ram |  | ['integer', 'null'] | Allocated RAM MB
serial_adapters |  | ['integer', 'null'] | How many serial adapters are connected to the IOU

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
console | ✔ | integer | console TCP port
ethernet_adapters | ✔ | integer | How many ethernet adapters are connected to the IOU
l1_keepalives | ✔ | boolean | Always up ethernet interface
name | ✔ | string | IOU VM name
nvram | ✔ | integer | Allocated NVRAM KB
path | ✔ | string | Path of iou binary
project_id | ✔ | string | Project UUID
ram | ✔ | integer | Allocated RAM MB
serial_adapters | ✔ | integer | How many serial adapters are connected to the IOU
vm_id | ✔ | string | IOU VM UUID

## DELETE /v1/projects/{project_id}/iou/vms/{vm_id}

Delete a IOU instance

### Parameters

- project_id: UUID for the project
- vm_id: UUID for the instance

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: Instance deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »